aboutsummaryrefslogtreecommitdiff
path: root/saga
diff options
context:
space:
mode:
authorEugene Sandulenko2005-01-28 12:54:09 +0000
committerEugene Sandulenko2005-01-28 12:54:09 +0000
commitff8094aad52d817f32cd0698ccf6fb38184e5752 (patch)
tree9d8f39882e25c053b842ebc3173c6f226aea4e70 /saga
parent9d64850be203804a8eb9355e707094174a245a45 (diff)
downloadscummvm-rg350-ff8094aad52d817f32cd0698ccf6fb38184e5752.tar.gz
scummvm-rg350-ff8094aad52d817f32cd0698ccf6fb38184e5752.tar.bz2
scummvm-rg350-ff8094aad52d817f32cd0698ccf6fb38184e5752.zip
Combine actordata.cpp and objectdata.cpp into itedata.cpp. These are
ITE specific and from other hand IHNM has these data in resources. svn-id: r16662
Diffstat (limited to 'saga')
-rw-r--r--saga/actor.cpp3
-rw-r--r--saga/actor.h2
-rw-r--r--saga/interface.cpp2
-rw-r--r--saga/itedata.cpp (renamed from saga/actordata.cpp)47
-rw-r--r--saga/itedata.h (renamed from saga/actordata.h)24
-rw-r--r--saga/module.mk3
-rw-r--r--saga/objectdata.cpp73
-rw-r--r--saga/objectdata.h53
-rw-r--r--saga/script.cpp3
-rw-r--r--saga/sfuncs.cpp2
10 files changed, 73 insertions, 139 deletions
diff --git a/saga/actor.cpp b/saga/actor.cpp
index f7bbc8c494..6474dd82a3 100644
--- a/saga/actor.cpp
+++ b/saga/actor.cpp
@@ -35,8 +35,7 @@
#include "saga/scene.h"
#include "saga/actor.h"
-#include "saga/actordata.h"
-#include "saga/objectdata.h"
+#include "saga/itedata.h"
#include "saga/stream.h"
#include "saga/interface.h"
#include "saga/events.h"
diff --git a/saga/actor.h b/saga/actor.h
index 572e0bb19c..32ea2812a0 100644
--- a/saga/actor.h
+++ b/saga/actor.h
@@ -27,7 +27,7 @@
#define SAGA_ACTOR_H__
#include "saga/sprite.h"
-#include "saga/actordata.h"
+#include "saga/itedata.h"
#include "saga/list.h"
#include "saga/saga.h"
diff --git a/saga/interface.cpp b/saga/interface.cpp
index 395d3a6120..c873830416 100644
--- a/saga/interface.cpp
+++ b/saga/interface.cpp
@@ -29,7 +29,7 @@
#include "saga/console.h"
#include "saga/font.h"
#include "saga/objectmap.h"
-#include "saga/objectdata.h"
+#include "saga/itedata.h"
#include "saga/rscfile_mod.h"
#include "saga/scene.h"
#include "saga/script.h"
diff --git a/saga/actordata.h b/saga/itedata.h
index 46bd997e1f..299cc365db 100644
--- a/saga/actordata.h
+++ b/saga/itedata.h
@@ -23,8 +23,8 @@
// Actor data table header file
-#ifndef SAGA_ACTORDATA_H
-#define SAGA_ACTORDATA_H
+#ifndef SAGA_ITEDATA_H
+#define SAGA_ITEDATA_H
namespace Saga {
@@ -60,6 +60,26 @@ struct ActorTableData {
extern ActorTableData ITE_ActorTable[ITE_ACTORCOUNT];
+enum {
+ kObjUseWith = 0x01,
+ kObjNotFlat = 0x02
+};
+
+struct ObjectTableData {
+ byte nameIndex;
+ int32 sceneIndex;
+ int16 x;
+ int16 y;
+ int16 z;
+ int32 spriteListResourceId;
+ byte scriptEntrypointNumber;
+ uint16 interactBits;
+};
+
+#define ITE_OBJECTCOUNT 39
+
+extern ObjectTableData ITE_ObjectTable[ITE_OBJECTCOUNT];
+
} // End of namespace Saga
#endif
diff --git a/saga/module.mk b/saga/module.mk
index 064d6ea77e..d28f57c823 100644
--- a/saga/module.mk
+++ b/saga/module.mk
@@ -2,7 +2,6 @@ MODULE := saga
MODULE_OBJS := \
saga/actor.o \
- saga/actordata.o \
saga/animation.o \
saga/console.o \
saga/events.o \
@@ -15,7 +14,7 @@ MODULE_OBJS := \
saga/interface.o \
saga/isomap.o \
saga/ite_introproc.o \
- saga/objectdata.o \
+ saga/itedata.o \
saga/objectmap.o \
saga/palanim.o \
saga/render.o \
diff --git a/saga/objectdata.cpp b/saga/objectdata.cpp
deleted file mode 100644
index 8b71a07ee7..0000000000
--- a/saga/objectdata.cpp
+++ /dev/null
@@ -1,73 +0,0 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2004-2005 The ScummVM project
- *
- * The ReInherit Engine is (C)2000-2003 by Daniel Balsom.
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
-
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- * $Header$
- *
- */
-
-// Actor data table
-#include "saga/saga.h"
-#include "saga/objectdata.h"
-
-namespace Saga {
-
-
-ObjectTableData ITE_ObjectTable[ITE_OBJECTCOUNT] = {
- { 8, 49, 1256, 760, 0, 9, 5, kObjNotFlat }, // Magic Hat
- { 9, 52, 1080, 1864, 0, 10, 4, kObjUseWith }, // Berries
- { 10, 259, 744, 524, 0, 11, 42, kObjUseWith }, // Card Key
- { 11, 0, 480, 480, 0, 12, 6, 0 }, // Foot Print
- { 12, 0, 480, 480, 0, 13, 38, kObjUseWith }, // Power Cell
- { 13, 28, 640, 412, 40, 14, 15, kObjUseWith }, // Digital Clock
- { 14, 0, 480, 480, 0, 15, 41, kObjUseWith }, // Oil Lamp
- { 15, 24, 868, 456, 35, 16, 13, kObjUseWith }, // Magnetic Key
- { 16, 0, 480, 480, 0, 17, 7, kObjUseWith }, // Plaster
- { 17, 249, 320, 476, 45, 18, 44, 0 }, // Trophy
- { 18, 0, 480, 480, 0, 19, 20, 0 }, // Coins
- { 19, 19, 600, 480, 0, 20, 8, 0 }, // Lens Fragments
- { 20, 0, 1012, 568, 80, 21, 10, kObjUseWith }, // Key to jail cell
- { 21, 0, 480, 480, 0, 22, 9, 0 }, // Remade lens
- { 22, 0, 480, 480, 0, 23, 21, 0 }, // Tycho's Map
- { 23, 0, 480, 480, 0, 24, 23, 0 }, // Silver Medallion
- { 24, 0, 480, 480, 0, 25, 24, 0 }, // Mud in Fur
- { 25, 0, 480, 480, 0, 26, 25, 0 }, // Gold Ring
- { 27, 13, 1036, 572, 0, 47, 14, kObjUseWith }, // Screwdriver
- { 28, 0, 480, 480, 0, 29, 26, 0 }, // Apple Token
- { 29, 0, 480, 480, 0, 30, 22, kObjUseWith }, // Letter from Elara
- { 30, 0, 164, 440, 0, 31, 16, kObjUseWith }, // Spoon
- { 32, 0, 480, 480, 0, 33, 43, 0 }, // Catnip
- { 33, 31, 580, 392, 0, 45, 11, 0 }, // Twigs
- { 35, 0, 468, 480, 0, 36, 12, kObjUseWith }, // Empty Bowl (also bowl of honey)
- { 37, 0, 480, 480, 0, 38, 45, kObjUseWith }, // Needle and Thread
- { 38, 25, 332, 328, 0, 39, 19, 0 }, // Rock Crystal
- { 39, 0, 480, 480, 0, 40, 0, kObjUseWith }, // Salve
- { 40, 269, 644, 416, 0, 41, 39, kObjNotFlat }, // Electrical Cable
- { 41, 12, 280, 516, 0, 42, 17, kObjUseWith }, // Piece of flint
- { 42, 5, 876, 332, 32, 65, 18, 0 }, // Rat Cloak
- { 43, 52, 556, 1612, 0, 49, 28, kObjUseWith | kObjNotFlat }, // Bucket
- { 48, 52, 732, 948, 0, 50, 27, kObjUseWith }, // Cup
- { 49, 52, 520, 1872, 0, 53, 29, 0 }, // Fertilizer
- { 50, 52, 1012, 1268, 0, 52, 30, 0 }, // Feeder
- { 51, 252, -20, -20, 0, 71, 32, kObjUseWith | kObjNotFlat }, // Bowl in jail cell
- { 53, 252, 1148, 388, 0, 70, 33, 0 }, // Loose stone block in jail cell
- { 26, 12, 496, 368, 0, 76, 31, 0 }, // Coil of Rope from Quarry
- { 54, 281, 620, 352, 0, 80, 46, 0 } // Orb of Storms in Dam Lab
-};
-
-} // End of namespace Saga
diff --git a/saga/objectdata.h b/saga/objectdata.h
deleted file mode 100644
index 9a66f97855..0000000000
--- a/saga/objectdata.h
+++ /dev/null
@@ -1,53 +0,0 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2004-2005 The ScummVM project
- *
- * The ReInherit Engine is (C)2000-2003 by Daniel Balsom.
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
-
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- * $Header$
- *
- */
-
-// Actor data table header file
-
-#ifndef SAGA_OBJECTDATA_H
-#define SAGA_OBJECTDATA_H
-
-namespace Saga {
-
-enum {
- kObjUseWith = 0x01,
- kObjNotFlat = 0x02
-};
-
-struct ObjectTableData {
- byte nameIndex;
- int32 sceneIndex;
- int16 x;
- int16 y;
- int16 z;
- int32 spriteListResourceId;
- byte scriptEntrypointNumber;
- uint16 interactBits;
-};
-
-#define ITE_OBJECTCOUNT 39
-
-extern ObjectTableData ITE_ObjectTable[ITE_OBJECTCOUNT];
-
-#endif
-
-} // End of namespace Saga
diff --git a/saga/script.cpp b/saga/script.cpp
index 7f6d0b78e5..7043decfb2 100644
--- a/saga/script.cpp
+++ b/saga/script.cpp
@@ -31,11 +31,10 @@
#include "saga/script.h"
#include "saga/stream.h"
#include "saga/interface.h"
-#include "saga/actordata.h"
+#include "saga/itedata.h"
#include "saga/scene.h"
#include "saga/events.h"
#include "saga/actor.h"
-#include "saga/objectdata.h"
#include "saga/objectmap.h"
namespace Saga {
diff --git a/saga/sfuncs.cpp b/saga/sfuncs.cpp
index 6d554c0e96..6d359c1421 100644
--- a/saga/sfuncs.cpp
+++ b/saga/sfuncs.cpp
@@ -33,7 +33,7 @@
#include "saga/font.h"
#include "saga/interface.h"
#include "saga/music.h"
-#include "saga/objectdata.h"
+#include "saga/itedata.h"
#include "saga/render.h"
#include "saga/sound.h"
#include "saga/sndres.h"
diff --git a/saga/actordata.cpp b/saga/itedata.cpp
index 014111d982..7ac6c2cbad 100644
--- a/saga/actordata.cpp
+++ b/saga/itedata.cpp
@@ -21,9 +21,9 @@
*
*/
// Actor data table
#include "saga/saga.h"
-#include "saga/actordata.h"
+#include "saga/itedata.h"
namespace Saga {
@@ -221,4 +221,47 @@ ActorTableData ITE_ActorTable[ITE_ACTORCOUNT] = {
{ 0, 9, 74, -20, -20, 0, 51, 145, 0, 5, 0, 0, 0} // sundial rat
};
+
+ObjectTableData ITE_ObjectTable[ITE_OBJECTCOUNT] = {
+ { 8, 49, 1256, 760, 0, 9, 5, kObjNotFlat }, // Magic Hat
+ { 9, 52, 1080, 1864, 0, 10, 4, kObjUseWith }, // Berries
+ { 10, 259, 744, 524, 0, 11, 42, kObjUseWith }, // Card Key
+ { 11, 0, 480, 480, 0, 12, 6, 0 }, // Foot Print
+ { 12, 0, 480, 480, 0, 13, 38, kObjUseWith }, // Power Cell
+ { 13, 28, 640, 412, 40, 14, 15, kObjUseWith }, // Digital Clock
+ { 14, 0, 480, 480, 0, 15, 41, kObjUseWith }, // Oil Lamp
+ { 15, 24, 868, 456, 35, 16, 13, kObjUseWith }, // Magnetic Key
+ { 16, 0, 480, 480, 0, 17, 7, kObjUseWith }, // Plaster
+ { 17, 249, 320, 476, 45, 18, 44, 0 }, // Trophy
+ { 18, 0, 480, 480, 0, 19, 20, 0 }, // Coins
+ { 19, 19, 600, 480, 0, 20, 8, 0 }, // Lens Fragments
+ { 20, 0, 1012, 568, 80, 21, 10, kObjUseWith }, // Key to jail cell
+ { 21, 0, 480, 480, 0, 22, 9, 0 }, // Remade lens
+ { 22, 0, 480, 480, 0, 23, 21, 0 }, // Tycho's Map
+ { 23, 0, 480, 480, 0, 24, 23, 0 }, // Silver Medallion
+ { 24, 0, 480, 480, 0, 25, 24, 0 }, // Mud in Fur
+ { 25, 0, 480, 480, 0, 26, 25, 0 }, // Gold Ring
+ { 27, 13, 1036, 572, 0, 47, 14, kObjUseWith }, // Screwdriver
+ { 28, 0, 480, 480, 0, 29, 26, 0 }, // Apple Token
+ { 29, 0, 480, 480, 0, 30, 22, kObjUseWith }, // Letter from Elara
+ { 30, 0, 164, 440, 0, 31, 16, kObjUseWith }, // Spoon
+ { 32, 0, 480, 480, 0, 33, 43, 0 }, // Catnip
+ { 33, 31, 580, 392, 0, 45, 11, 0 }, // Twigs
+ { 35, 0, 468, 480, 0, 36, 12, kObjUseWith }, // Empty Bowl (also bowl of honey)
+ { 37, 0, 480, 480, 0, 38, 45, kObjUseWith }, // Needle and Thread
+ { 38, 25, 332, 328, 0, 39, 19, 0 }, // Rock Crystal
+ { 39, 0, 480, 480, 0, 40, 0, kObjUseWith }, // Salve
+ { 40, 269, 644, 416, 0, 41, 39, kObjNotFlat }, // Electrical Cable
+ { 41, 12, 280, 516, 0, 42, 17, kObjUseWith }, // Piece of flint
+ { 42, 5, 876, 332, 32, 65, 18, 0 }, // Rat Cloak
+ { 43, 52, 556, 1612, 0, 49, 28, kObjUseWith | kObjNotFlat }, // Bucket
+ { 48, 52, 732, 948, 0, 50, 27, kObjUseWith }, // Cup
+ { 49, 52, 520, 1872, 0, 53, 29, 0 }, // Fertilizer
+ { 50, 52, 1012, 1268, 0, 52, 30, 0 }, // Feeder
+ { 51, 252, -20, -20, 0, 71, 32, kObjUseWith | kObjNotFlat }, // Bowl in jail cell
+ { 53, 252, 1148, 388, 0, 70, 33, 0 }, // Loose stone block in jail cell
+ { 26, 12, 496, 368, 0, 76, 31, 0 }, // Coil of Rope from Quarry
+ { 54, 281, 620, 352, 0, 80, 46, 0 } // Orb of Storms in Dam Lab
+};
+
} // End of namespace Saga
@@ -21,9 +21,9 @@
*
*/
-// Actor data table
+// Actor and Object data tables
#include "saga/saga.h"